;; Generated package description from vundo.el  -*- no-byte-compile: t -*-
(define-package "vundo" "2.3.0.0.20241225.170413" "Visual undo tree" '((emacs "28.1")) :commit "d792738a5e4da73e619ad9c47dc34a3566445871" :authors '(("Yuan Fu" . "casouri@gmail.com")) :maintainer '("Yuan Fu" . "casouri@gmail.com") :keywords '("undo" "text" "editing") :url "https://github.com/casouri/vundo")
